@@ -273,7 +273,7 @@ path_part (char *file, char *path, int pathlen)
 }
 
 char *				/* like strstr(), but nocase */
-nocasestrstr (char *s, char *wanted)
+nocasestrstr (const char *s, const char *wanted)
 {
 	register const int len = strlen (wanted);
 
@@ -1079,7 +1079,6 @@ static const domain_t domain[] =
 		{"UA", N_("Ukraine") },
 		{"UG", N_("Uganda") },
 		{"UK", N_("United Kingdom") },
-		{"UM", N_("US Minor Outlying Islands") },
 		{"US", N_("United States of America") },
 		{"UY", N_("Uruguay") },
 		{"UZ", N_("Uzbekistan") },
@@ -1178,7 +1177,8 @@ int my_poptParseArgvString(const char * s, int * argcPtr, char *** argvPtr) {
 		if (*src != quote) *buf++ = '\\';
 	    }
 	    *buf++ = *src;
-	} else if (isspace((unsigned char) *src)) {
+	/*} else if (isspace((unsigned char) *src)) {*/
+	} else if (*src == ' ') {
 	    if (*argv[argc]) {
 		buf++, argc++;
 		if (argc == argvAlloced) {
@@ -1233,7 +1233,7 @@ int my_poptParseArgvString(const char * s, int * argcPtr, char *** argvPtr) {
 }
 
 int
-util_exec (char *cmd)
+util_exec (const char *cmd)
 {
 	int pid;
 	char **argv;
@@ -1265,6 +1265,31 @@ util_exec (char *cmd)
 #endif
 }
 
+int
+util_execv (char * const argv[])
+{
+	int pid, fd;
+
+#ifndef WIN32
+	pid = fork ();
+	if (pid == -1)
+		return -1;
+	if (pid == 0)
+	{
+		/* Now close all open file descriptors except stdin, stdout and stderr */
+		for (fd = 3; fd < 1024; fd++) close(fd);
+		execv (argv[0], argv);
+		_exit (0);
+	} else
+	{
+		return pid;
+	}
+#else
+	spawnv (_P_DETACH, argv[0], argv);
+	return 0;
+#endif
+}
+
 unsigned long
 make_ping_time (void)
 {
@@ -1647,7 +1672,7 @@ str_hash (const char *key)
 guint32
 str_ihash (const unsigned char *key)
 {
-	const char *p = key;
+	const unsigned char *p = key;
 	guint32 h = rfc_tolowertab [(guint)*p];
 
 	if (h)
@@ -1656,3 +1681,40 @@ str_ihash (const unsigned char *key)
 
 	return h;
 }
+
+/* features: 1. "src" must be valid, NULL terminated UTF-8 */
+/*           2. "dest" will be left with valid UTF-8 - no partial chars! */
+
+void
+safe_strcpy (char *dest, const char *src, int bytes_left)
+{
+	int mbl;
+
+	while (1)
+	{
+		mbl = g_utf8_skip[*((unsigned char *)src)];
+
+		if (bytes_left < (mbl + 1)) /* can't fit with NULL? */
+		{
+			*dest = 0;
+			break;
+		}
+
+		if (mbl == 1)	/* one byte char */
+		{
+			*dest = *src;
+			if (*src == 0)
+				break;	/* it all fit */
+			dest++;
+			src++;
+			bytes_left--;
+		}
+		else				/* multibyte char */
+		{
+			memcpy (dest, src, mbl);
+			dest += mbl;
+			src += mbl;
+			bytes_left -= mbl;
+		}
+	}
+}
